@@ -11,7 +11,7 @@ import commands
 
 win32 = (sys.platform=='win32')
 
-def newTempfile(suffix=None):
+def newTempfile(suffix=''):
     return tempfile.mktemp(suffix=suffix)
 
 
@@ -22,4 +22,5 @@ def runcmd(cmd):
 
     else:      
         status, output = commands.getstatusoutput(cmd)
+        print cmd, status,output
         return status, output
